package net.wanji.databus.dao.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import net.wanji.databus.bo.CrossDirDataHistAvgBO;
import net.wanji.databus.dto.MetricHistDTO;
import net.wanji.databus.po.CrossDirDataHistPO;
import net.wanji.databus.po.CrossDirDataHistPOExt;
import net.wanji.databus.vo.CrossDirDataHistVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Collection;
import java.util.List;

/**
 * @author duanruiming
 * @date 2023/03/10 21:09
 */
@Mapper
public interface CrossDirDataHistMapper extends BaseMapper<CrossDirDataHistPO> {
    void insertBatch(@Param("list")List<CrossDirDataHistPO> list);
    void deleteBatch(@Param("list") Collection<String> crossIds);

    List<CrossDirDataHistPO> selectByCrossIdAndTimestamp(String crossId, long preSeconds);

    List<CrossDirDataHistPO> selectByCrossIdDirAndTimestamp(String crossId, Integer dir, long preSeconds);

    List<CrossDirDataHistAvgBO> selectByCrossIdInOutTimestamp(String crossId, Integer inOutType, long preSeconds, long endSeconds);

    List<CrossDirDataHistPO> selectNoPark(String crossId, Integer dir, long currentSeconds, long preSeconds);

    List<CrossDirDataHistPO> selectPhaseQueue(String crossId, Integer dir, long currentSeconds, long preSeconds);

    List<CrossDirDataHistPO> selectNoParkEnd(String crossId, Integer dir, long currentSeconds, long preSeconds);

    List<CrossDirDataHistPO> selectPhaseQueueEnd(String crossId, Integer dir, long currentSeconds, long preSeconds);

    List<MetricHistDTO> selectMetricHistDTO(String crossId, int startStamp, int endStamp, int dir);

    List<CrossDirDataHistPO> selectByCrossIdAndStartEnd(String crossId, int startStamp, int endStamp);

    /**
     * 方向级查询
     *
     * @param crossId     路口ID
     * @param startStamp  开始时间
     * @param endStamp    截止时间
     * @param dirTypeList 方向
     * @param granularity 时段
     * @return
     */
    List<CrossDirDataHistVO> selectByCrossIdAndStartEndDir(String crossId, String startStamp, String endStamp, List<Integer> dirTypeList, String granularity);

    Integer selectMaxDelayTime(String crossId, Integer dirType, Integer inOutType, int startStamp, int endStamp);

    Double selectMaxQueueLength(String crossId, Integer dirType, Integer inOutType, int startStamp, int endStamp);

    Double selectMaxSaturation(String crossId, Integer dirType, Integer inOutType, int startStamp, int endStamp);

    Double selectMaxGreenLightEfficiency(@Param("crossId") String crossId, @Param("dirCode") Integer dirCode,
                                         @Param("code")Integer code, @Param("startTimeStamp") int startTimeStamp,
                                         @Param("endTimeStamp") int endTimeStamp);

    List<CrossDirDataHistPOExt> selectByMetrics(String crossId, int dirInt, int startTimeStamp, int endTimeStamp);

    List<CrossDirDataHistPO> selectByCrossIdsDirsAndTimestamp(List<String> crossIdList, List<Integer> dirCodeList, int startTimeStamp, int endTimeStamp);

    List<CrossDirDataHistPO> selectByCrossIdDirsAndTimestamp(String crossId, List<Integer> dirCodeList, int startTimeStamp, int endTimeStamp);

    List<CrossDirDataHistPO> selectByCrossDirAndTimeSection(
            @Param("crossId") String crossId,
            @Param("dirCode") Integer dirCode,
            @Param("boStartDayStr") String boStartDayStr,
            @Param("boEndDayStr") String boEndDayStr,
            @Param("startHourMinuteStr") String startHourMinuteStr,
            @Param("endHourMinuteStr") String endHourMinuteStr
    );

    List<CrossDirDataHistPO> selectByCrossDirsAndTimeSection(
            @Param("crossId") String crossId,
            @Param("dirCodeList") List<Integer> dirCodeList,
            @Param("boStartDayStr") String boStartDayStr,
            @Param("boEndDayStr") String boEndDayStr,
            @Param("startHourMinuteStr") String startHourMinuteStr,
            @Param("endHourMinuteStr") String endHourMinuteStr
    );

    List<CrossDirDataHistPO> selectByTimeSection(String boStartDayStr, String boEndDayStr, String startHourMinuteStr, String endHourMinuteStr);

    List<CrossDirDataHistPOExt> selectExtByTimeSection(String boStartDayStr, String boEndDayStr, String startHourMinuteStr, String endHourMinuteStr);
}
