package net.wanji.databus.dubbo;

import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.common.URL;
import org.apache.dubbo.rpc.Invocation;
import org.apache.dubbo.rpc.Invoker;
import org.apache.dubbo.rpc.cluster.loadbalance.AbstractLoadBalance;
import org.apache.dubbo.rpc.cluster.loadbalance.RandomLoadBalance;

import java.util.List;

/**
 * @Description: 针对开发场景做自定义dubbo负载均衡策略，可按IP规则做路由配置
 * @Date 2020/8/23 10:33
 */
@Slf4j
public class DevLoadBalance extends AbstractLoadBalance {
    @Override
    protected <T> Invoker<T> doSelect(List<Invoker<T>> invokers, URL url, Invocation invocation) {
        String devIps = System.getProperty("dev_current_ips");
        log.info("=====dev_current_ips===== : {}", devIps);
        if (StringUtils.isNotBlank(devIps)) {
            String[] patterns = devIps.split(",");
            if (ArrayUtils.isNotEmpty(patterns)) {
                //匹配开发机器路由
                for (String pattern : patterns) {
                    for (Invoker<T> invoker : invokers) {
                        if (invoker.getUrl().getHost().matches(pattern)) {
                            log.info("=====匹配开发机器路由负载均衡地址地址===== : {}", invoker.getUrl().toString());
                            return invoker;
                        }
                    }
                }
            }
        }
        //默认随机策略
        Invoker<T> invoker = new RandomLoadBalance().select(invokers, url, invocation);
        log.info("=======默认随机策略负载均衡地址======= : {}", invoker.getUrl().toString());
        return invoker;
    }
}
