package net.wanji.databus.provider.client.identityManagement;

import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.Node;
import net.wanji.databus.entity.client.identitymanagement.AuthorityBusinessAccount;

import java.util.List;
import java.util.Set;

/**
 * @Description:
 * @Author wanji
 * @Date 2019/11/27 18:47
 **/
public interface AuthorityBusinessAccountProvider extends BaseDubboInterface<AuthorityBusinessAccount> {

    /**
     * @Description: 根据企业用户和权限类型获取该类型下所有权限类型id
     *
     * @param coUserId
     * @param type
     * @return java.util.List<java.lang.String>
     * @Author wanji
     * @Date 2019/11/30 15:20
     **/
    Set<String> getAuthObjIdList(String coUserId, String type, String appId) throws DubboProviderException;

    /**
     * @Description: 根据名片id和权限类型获取该类型下所有权限类型id集合
     *
     * @param cardId
     * @param type
     * @return java.util.Set<java.lang.String>
     * @Author wanji
     * @Date 2019/12/9 17:07
     **/
    Set<String> getAuthObjIdListByCardId(String cardId, String type, String appId) throws DubboProviderException;

    /**
     * @Description: 获取授权资源树形结构列表
     *
     * @param type
     * @param id
     * @return java.util.List<net.wanji.common.framework.rest.Node>
     * @Author wanji
     * @Date 2019/12/4 15:24
     **/
    List<Node> queryAuthList(String type, String id, String authObjCatalogId) throws DubboProviderException;

    /**
     * @Description: 对认证企业用户进行授权
     *
     * @param type
     * @param companyUserId
     * @param addAuthorityObjectIdList
     * @param deleteAuthorityObjectIdList
     * @return boolean
     * @Author wanji
     * @Date 2019/12/11 16:30
     **/
    boolean approve(String type, String companyUserId,String appId, List<String> addAuthorityObjectIdList, List<String> deleteAuthorityObjectIdList) throws DubboProviderException;

    /**
     * @Author wanji
     * @Description 根据名片id和相关参数获取授权资源
     * @Date 16:06 2020/7/24
     * @Param [cardId, type, authObjCatalog, appId]
     * @return java.util.Set<java.lang.String>
     * @throws
     */
    Set<String> queryAuthResourceByCard(String cardId, String type, String authObjCatalog, String appId) throws DubboProviderException;
}
