package net.wanji.databus.provider.develop.servicedevelop.appmanage;

import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.Node;
import net.wanji.databus.entity.client.frontdevelop.ApplicationAllInfoRepo;
import net.wanji.databus.entity.develop.servicedevelop.appmanage.Application;
import net.wanji.databus.entity.develop.servicedevelop.appmanage.Module;
import net.wanji.databus.entity.develop.servicedevelop.appmanage.ResourceInfo;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author wanji
 * @Date 2020/3/16 17:21
 */
public interface ApplicationProvider extends BaseDubboInterface<Application> {

    /**
     * 系统下模块
     *
     * @param id
     * @return
     * @throws DubboProviderException
     */
    List<Module> applicationTree(String id) throws DubboProviderException;

    /**
     * @param
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 获取系统及模块树，包含服务编排
     * @Author wanji
     * @Date 2020/3/24 17:37
     **/
    List<Node> listModuleByApp(String type) throws DubboProviderException;

    /**
     * @param cardId
     * @return java.util.List<net.wanji.design.entity.design.servicepublish.Application>
     * @Description: 根据名片id查询有权限的系统集合
     * @Author wanji
     * @Date 2020/3/9 16:03
     **/
    List<Application> listApplicationsByCard(String cardId) throws DubboProviderException;

    List<Application> listApplication(Map<String, Object> info) throws DubboProviderException;

    /**
     * @param authObjIdList
     * @return java.util.List<net.wanji.common.framework.rest.Node>
     * @Description: 获取应用系统/菜单二级树
     * @Author wanji
     * @Date 2020/3/19 16:44
     **/
    List<Node> getAllTreeRes(List<String> authObjIdList) throws DubboProviderException;

    /**
     * @param id
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 根据应用id获取跟应用所有相关模块的信息
     * @Author peng.zhang6
     * @Date 2020/4/8 14:44
     **/
    ApplicationAllInfoRepo getApplicationAllInfo(String id) throws DubboProviderException;

    /**
     * @return java.util.List<Application>
     * @throws
     * @Author wanji
     * @Description 获取该业务账号所管理的应用
     * @Date 13:40 2020/6/1
     * @Param [cardId]
     */
    List<Application> listManageAppsByCard(String cardId) throws Exception;

    List<ApplicationAllInfoRepo> getResourcesWithType() throws DubboProviderException;

    JsonViewObject saveResource(ResourceInfo resourceInfo) throws DubboProviderException;

    JsonViewObject updateResource(ResourceInfo resourceInfo) throws DubboProviderException;

    List<Node> getWebPortalAuthObjListNode(List<String> authObjIdList, String type, Boolean isFilterUnAuthNodes) throws DubboProviderException;

    List<Node> getMobilePortalAuthObjListNode(List<String> authObjIdList, String type, Boolean isFilterUnAuthNodes) throws DubboProviderException;

    /**
     * @param appId         应用id
     * @param exportConfigs 导出配置项，根据配置项导出内容
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 根据应用id，导出应用；导出过程异步执行，这里仅返回发起导出请求调用结果
     * 1、每个配置项1个状态(额外有一个文件生成)，初始化到缓存中，状态分三中，每个配置项有三种，success成功-failed失败-unreachable未到达
     * 2、导出的时候生成1个id，用appId，不能并发导出相同应用，导出之前做判断
     * 3、每次导出记录开始-结束时间
     * @Author
     * @Date 2020/6/30 9:11
     **/
    JsonViewObject exportApp(String appId, List<String> exportConfigs) throws DubboProviderException;

    /**
     * @param appId 应用id
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 根据应用id，查询应用导出状态
     * 状态在发起导出时初始化/重置，放到缓存中，服务重启后清空，用户可以查询上一次导出记录并下载
     * 状态中需要记录：
     * 1、导出人名称-username
     * 2、应用整体导出完成状态
     * 3、文件生成状态及文件下载地址
     * 4、开始时间，结束时间，
     * 5、各配置项中导出状态，数据处理条数
     * @Author
     * @Date 2020/6/30 9:19
     **/
    JsonViewObject queryExportAppStatus(String appId) throws DubboProviderException;

    /**
     * @param userId     当前操作用户id
     * @param importType 导入模式，skip-重复数据跳过，update-重复数据更新
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 导入应用
     * 阻塞导入应用定义成功后返回，导入状态维护参考导出
     * @Author
     * @Date 2020/6/30 9:33
     **/
    JsonViewObject importApp(byte[] excel, String userId, String importType, String exportConfigs) throws DubboProviderException, IOException;

    /**
     * @param userId 当前操作用户id
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 应用导入状态查询，根据用户id查询，用户id从token中解析，不需传递
     * @Author
     * @Date 2020/6/30 9:33
     **/
    JsonViewObject queryImportAppStatus(String userId) throws DubboProviderException;

    List<Application> findSpecificApplication() throws DubboProviderException;

    List<Node> listWebAndMobileApp() throws DubboProviderException;


    /**
     * @param param
     * @return net.wanji.common.framework.rest.JsonViewObject
     * @Description: 应用克隆
     * @Author shuang.dai
     * @Date 2020/8/10 11:31
     **/
    JsonViewObject cloneApp(Map<String, Object> param) throws DubboProviderException;

    /**
     * @param typeList
     * @return Map
     * @Description: 移动端应用查询
     * @Author shuang.dai
     * @Date 2020/8/12 15：19
     **/
    Map<String, Object> queryAppAddress(List<String> typeList) throws DubboProviderException;

    /**
     * @param
     * @return List
     * @Description: 移动端门户查询
     * @Author shuang.dai
     * @Date 2020/8/12 15：19
     **/
    List<Map<String, Object>> queryMobileportal(String userId) throws DubboProviderException;

    JsonViewObject listConnectionApp();

    List<Node> listServiceTreeByType(String type) throws Exception;
}
