package net.wanji.databus.provider.develop.servicedevelop.bpm;

import com.alibaba.fastjson.JSONArray;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.Page;
import net.wanji.databus.entity.develop.servicedevelop.appmanage.Application;
import net.wanji.databus.entity.develop.servicedevelop.bpm.processmanager.*;
import net.wanji.databus.entity.identity.identity.BusinessAccount;
import net.wanji.databus.entity.integration.messagecenter.MessageTopic;
import net.wanji.databus.entity.integration.servicegateway.m2a.M2AMail;

import java.util.List;
import java.util.Map;

/**
 * @Description: 流程业务接口
 * @Author: xinrui.li
 * @Date: 2020/04/20/14:40
 */
public interface BpmDeployBusinessProvider {

    /**
     * 部署/取消部署接口
     *
     * @param params
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/18 19:06
     */
    JsonViewObject changeDeployStatus(List<Map<String, Object>> params) throws DubboProviderException;

    /**
     * 启动流程
     *
     * @param userId
     * @param workflowId     流程实例id
     * @param lastNodeUserId 下节点指定处理人
     * @param param          表单信息
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/20 14:56
     */
    JsonViewObject startWorkflow(String workflowId, String userId, List<String> lastNodeUserId, Map<String, Object> param);

    /**
     * 根据流程节点ID和流程id获取流程节点
     *
     * @param nodeId
     * @param workflowId
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/21 16:39
     */
    WorkflowNodeDefinition getWorkflowNodeByNodeId(String nodeId, String workflowId) throws DubboProviderException;

    /**
     * 根据taskID获取
     *
     * @param taskId
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/4/21 16:39
     */
    WorkflowTask getWorkfloeTaskByTaskId(String taskId) throws DubboProviderException;

    /**
     * 根据taskID获取
     *
     * @param workflowLogRe 任务表
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/4/21 16:39
     */
    void updateWorkflowLogRe(WorkflowTask workflowLogRe) throws DubboProviderException;

    /**
     * 根据json规则获取业务账号
     *
     * @param jsonArray
     * @param userId
     * @param appId
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 9:21
     */
    List<String> getBussinessAcountByRule(JSONArray jsonArray, String userId, String appId) throws DubboProviderException;

    /**
     * 放行
     *
     * @param id             任务自定义id
     * @param userId         userId
     * @param status         放行状态（pass，back）
     * @param remark         放行备注
     * @param map            放行条件
     * @param lastNodeUserId 下节点指定处理人
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 14:27
     */
    JsonViewObject completeTask(String id, String userId, String status, String remark, Map<String, Object> map, List<String> lastNodeUserId);

    /**
     * 暂停
     *
     * @param id 流程实例id
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 14:27
     */
    JsonViewObject pause(String id);

    /**
     * 激活
     *
     * @param id 流程实例id
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 14:27
     */
    JsonViewObject active(String id);

    /**
     * 销毁
     *
     * @param id 流程实例id
     * @return
     * @Author xinrui.li
     * @Date 2020/4/22 14:27
     */
    JsonViewObject destory(String id);

    /**
     * 获取流程实例详情, 查日志表
     *
     * @param
     * @return
     * @Author xinrui.li
     * @Date 2020/4/22 16:48
     */
    JsonViewObject findWorkflowDetail(String id);

    /**
     * 根据 id获取委派人
     *
     * @param id 任务自定义id
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:16
     */
    JsonViewObject findAppointUser(String id) throws DubboProviderException;

    /**
     * 保存日志表
     *
     * @param workflowLogRe
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:28
     */
    void saveWorkflowTask(WorkflowTask workflowLogRe) throws DubboProviderException;

    /**
     * 保存notice表
     *
     * @param workflowNotice
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:28
     */
    void saveWorkflowNotice(WorkflowNotice workflowNotice) throws DubboProviderException;


    /**
     * 删除完成的notice表
     *
     * @param param
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:28
     */
    void deleteWorkflowNotice(Map<String, Object> param) throws DubboProviderException;

    /**
     * 查询通知表的数据
     *
     * @param param
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/4/22 18:28
     */
    List<WorkflowNotice> findWorkflowNoticeByMap(Map<String, Object> param) throws DubboProviderException;

    /**
     * 保存notice表
     *
     * @param workflowNotice
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/4/22 18:28
     */
    void updateWorkflowNotice(WorkflowNotice workflowNotice) throws DubboProviderException;

    /**
     * 流程实例表findbymap
     *
     * @param map
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:31
     */
    List<WorkflowInst> getWorkflowInstByMap(Map<String, Object> map) throws DubboProviderException;

    /**
     * 流程task表findbymap
     *
     * @param map
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:31
     */
    List<WorkflowTask> getWorkflowTaskByMap(Map<String, Object> map) throws DubboProviderException;

    /**
     * 更新流程实例表
     *
     * @param workflowInst
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/22 18:34
     */
    void updateWorkflowInst(WorkflowInst workflowInst) throws DubboProviderException;

    /**
     * 查询流程实例
     *
     * @param id 流程实例id
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/5/24
     */
    WorkflowInst findWorkflowInstById(String id) throws DubboProviderException;

    /**
     * 保存任务人
     *
     * @param workflowTaskPersonList
     * @return
     * @Author xinrui.li
     * @Date 2020/4/26 9:20
     */
    void saveWorkflowTaskPerson(List<WorkflowTaskPerson> workflowTaskPersonList);

    /**
     * 查询任务人
     *
     * @param param
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/4/26 9:20
     */
    List<WorkflowTaskPerson> findWorkflowTaskPersonByMap(Map<String, Object> param) throws DubboProviderException;

    /**
     * 保存邮件日志
     *
     * @param mailLog
     * @return
     * @throws DubboProviderException
     * @Author xinrui.li
     * @Date 2020/4/26 9:20
     */
    void saveMailLog(MailLog mailLog) throws DubboProviderException;

    /**
     * 根据id查询业务账号
     *
     * @param userId
     * @return
     * @throws DubboProviderException
     * @Author shuang.dai
     * @Date 2020/5/25
     */
    BusinessAccount getBusinessAccountById(String userId) throws DubboProviderException;

    /**
     * 委派人查询
     *
     * @param id 任务自定义id
     * @return
     */
    JsonViewObject appointNames(String id);

    /**
     * 委派人保存
     *
     * @param id       任务自定义id
     * @param userIds  用户id
     * @param operator 操作人
     * @return
     */
    JsonViewObject saveAppointUsers(String id, List<String> userIds, String operator);

    /**
     * 已办查询
     *
     * @param page
     * @param param
     * @return
     */
    JsonViewObject findByPageFinish(Page page, Map<String, Object> param);

    /**
     * 待办查询
     *
     * @param page
     * @param param
     * @return
     */
    JsonViewObject findByPageDelay(Page page, Map<String, Object> param);

    /**
     * 保存会签
     *
     * @param workflowTaskCountersign
     * @return
     * @throws DubboProviderException
     */
    void saveWorkflowTaskCountersign(WorkflowTaskCountersign workflowTaskCountersign) throws DubboProviderException;

    /**
     * 保存会签
     *
     * @param param
     * @return
     * @throws DubboProviderException
     */
    List<WorkflowTaskCountersign> queryWorkflowTaskCountersign(Map<String, Object> param) throws DubboProviderException;

    /**
     * 查询邮件配置
     *
     * @param id
     * @return M2AMail
     * @throws DubboProviderException
     */
    M2AMail findMailById(String id) throws DubboProviderException;

    /**
     * 查询总体信息
     *
     * @param param
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject findAppAndTaskList(Map<String, Object> param) throws DubboProviderException;

    /**
     * 查询我的流程信息
     *
     * @param param
     * @param page
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject workflowAllDetail(Page page, Map<String, Object> param) throws DubboProviderException;

    /**
     * 查询id查询应用
     *
     * @param id 应用id
     * @return
     * @throws DubboProviderException
     */
    Application findApplicationById(String id) throws DubboProviderException;

    /**
     * 根据流程实例id查询流程是否正常运行
     *
     * @param workflowInstId
     * @return
     */
    boolean isEnd(String workflowInstId);

    /**
     * 根据流程实例id查询流程是否正常运行
     *
     * @param param
     * @return
     * @throws DubboProviderException
     */
    List<MessageTopic> findTopicByMap(Map<String, Object> param) throws DubboProviderException;

    /**
     * 根据流程实例id删除流程
     *
     * @param workflowInstId
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject deleteWorkflowTask(String workflowInstId) throws DubboProviderException;

    /**
     * 查询我的申请
     *
     * @param page
     * @param param
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject queryMyApplication(Page page, Map<String, Object> param) throws DubboProviderException;

    /**
     * 根据任务状态查询任务详情
     *
     * @param page
     * @param param
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject queryTaskDetailByTaskStatus(Page page, Map<String, Object> param) throws DubboProviderException;

    /**
     * 根据id查询表单信息
     *
     * @param id
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject queryFormDataById(String id) throws DubboProviderException;

    List<WorkflowTask> findByMapDesc(Map<String, Object> workflowMap) throws DubboProviderException;

    /**
     * 保存流程实例
     *
     * @param workflowInst
     * @return
     * @throws DubboProviderException
     */
    void saveWorkflowInst(WorkflowInst workflowInst) throws DubboProviderException;

    /**
     * 加签查询
     *
     * @param id
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject countersignUser(String id) throws DubboProviderException;

    /**
     * 加签保存
     *
     * @param id
     * @param userIds
     * @return
     * @throws DubboProviderException
     */
    JsonViewObject saveAddSignUser(String id, List<String> userIds) throws DubboProviderException;
}
