package net.wanji.databus.provider.develop.servicedevelop.bpm;

import com.alibaba.fastjson.JSONArray;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.Node;
import net.wanji.databus.entity.develop.servicedevelop.bpm.processmanager.WorkflowDefinition;
import net.wanji.databus.entity.identity.identity.BusinessAccountGroup;

import java.util.List;
import java.util.Map;


/**
 * 类描述: 流程定义模块
 * 流程CRUD
 *
 * @Author
 * @Date 2019/8/26 9:59
 */
public interface WorkflowDefinitionProvider extends BaseDubboInterface<WorkflowDefinition> {

    /**
     * 描述: 查询全部流程，按照流程类型名称分组，不查询structure(无用字段，出于减少传输量考虑)
     *
     * @return com.alibaba.fastjson.JSONArray
     * @Author
     * @Date 2019/9/2 18:12
     **/
    JSONArray findDetailAll() throws DubboProviderException;


    /**
     * @param
     * @return
     * @Description 新建流程之后保存流程详细信息
     * @Author xinrui.li
     * @Date 2020/4/16 13:21
     */
    JsonViewObject saveWorkflowDetail(WorkflowDefinition workflowDefinition) throws DubboProviderException;

    /**
     * @param
     * @return
     * @Description 通过应用ID获取组织信息树状结构
     * @Author xinrui.li
     * @Date 2020/4/17 17:58
     */
    JsonViewObject findCascadeInfoByAppId(String appId) throws DubboProviderException;



    /**
     * @param
     * @return
     * @Description 通过应用ID获取组织信息树状结构, 并拼接成只显示部门
     * @Author xinrui.li
     * @Date 2020/4/17 17:58
     */
    List<Node> findDepartmentInfoByAppId(String appId) throws DubboProviderException;

    /**
     * @param
     * @return
     * @Description 通过应用ID获取组织信息树状结构, 并拼接成只显示岗位
     * @Author xinrui.li
     * @Date 2020/4/17 17:58
     */
    List<Node> findPositionInfoByAppId(String appId) throws DubboProviderException;

    /**
     * @param
     * @return
     * @Description 通过应用ID获取组织信息树状结构, 并拼接成只显示业务账号
     * @Author xinrui.li
     * @Date 2020/4/17 17:58
     */
    List<Node> findBussinessAccountInfoByAppId(String appId) throws DubboProviderException;

    /**
     * @Description 克隆流程
     *
     * @param
     * @return
     * @Author xinrui.li
     * @Date 2020/4/28 11:01
     */
    JsonViewObject cloneWorkflow(String id, String name,String version,String typeId,String remark) throws DubboProviderException;

    /**
     * @Description 查询所有应用所有流程
     *
     * @param
     * @return
     * @Author shuang.dai
     * @Date 2020/08/04
     */
    List<Node> queryAppWorkflow(Map<String,Object> map) throws DubboProviderException;

    /**
     * @Description 查询流程分类和已部署的流程
     *
     * @param
     * @return
     * @Author shuang.dai
     * @Date 2020/08/27
     */
    JsonViewObject queryWorkflowTypeTree(Map<String, Object> map);


    /**
     * @Description 查询账号组
     *
     * @param
     * @return
     * @Author shuang.dai
     */
    List<BusinessAccountGroup> queryGroup(String appId) throws DubboProviderException;
}
