package net.wanji.databus.provider.develop.servicedevelop.bpm;

import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.Page;

import java.util.List;
import java.util.Map;

/**
 * @Description: 流出操作对外暴露接口
 * @Author: xinrui.li
 * @Date: 2020/04/27/13:48
 */
public interface WorkflowDisposeProvider {
    /**
     * 下面的id 全部为流程实例表主键ID
     *
     * @return workflowinst
     * @Description 启动流程
     * @Author xinrui.li
     * @Date 2020/4/22 15:58
     */
    JsonViewObject start(String workflowId, String userId, List<String> lastNodeUserId, Map<String, Object> param);

    /**
     * @param
     * @return
     * @Description 暂停
     * @Author xinrui.li
     * @Date 2020/4/22 16:30
     */
    JsonViewObject pause(String id);


    /**
     * @param
     * @return
     * @Description 激活
     * @Author xinrui.li
     * @Date 2020/4/22 16:30
     */
    JsonViewObject active(String id);

    /**
     * @param map: id taskId status：同意:pass/不同意:back remark:意见 Map<String,Object>params()
     * @return
     * @Description 放行
     * @Author xinrui.li
     * @Date 2020/4/22 16:31
     */
    JsonViewObject completeTask(Map<String, Object> map, String id, String userId, String status, String remark, List<String> lastNodeUserId);

    /**
     * @param
     * @return
     * @Description 销毁
     * @Author xinrui.li
     * @Date 2020/4/22 16:31
     */
    JsonViewObject destory(String id);

    /**
     * 流程详情
     *
     * @param id 流程实例id
     * @return
     */
    JsonViewObject findWorkflowDetail(String id);

    /**
     * @param
     * @return content里面的返回值 JsonViewObject.content: List<String>  人的id
     * @Description 根据当前任务获取委派人
     * @Author xinrui.li
     * @Date 2020/4/22 16:48
     */
    JsonViewObject findAppointUser(String id) throws DubboProviderException;

    /**
     * 委派人查询
     *
     * @param id 任务id
     * @return
     */
    JsonViewObject appointNames(String id);

    /**
     * 委派人保存
     *
     * @param id      任务自定义id
     * @param userIds
     * @return
     */
    JsonViewObject saveAppointUsers(String id, List<String> userIds,String operator);

    /**
     * 已办查询
     *
     * @param page
     * @param param
     * @return
     */
    JsonViewObject findFinishByPage(Page page, Map<String, Object> param);

    /**
     * 待办查询
     *
     * @param page
     * @param param
     * @return
     */
    JsonViewObject findBacklogByPage(Page page, Map<String, Object> param);

    /**
     * 加签人查询
     *
     * @param id 任务id
     * @return
     */
    JsonViewObject countersignUser(String id) throws DubboProviderException;

    /**
     * 加签人保存
     *
     * @param id 任务id
     * @return
     */
    JsonViewObject saveAddSignUser(String id,List<String> userIds) throws DubboProviderException;
}
