package net.wanji.databus.provider.identity.identity;

import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.Node;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.databus.entity.identity.identity.AccountMappings;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author wanji
 * @Date 2019/11/27 18:47
 **/
public interface AccountMappingsProvider extends BaseDubboInterface<AccountMappings> {

    /**
     * @Description: 获取待生成名片的企业用户列表
     *
     * @param  disabled
     * @return java.util.List<net.wanji.common.identity.rest.Node>
     * @Author wanji
     * @Date 2019/11/28 15:28
     **/
    List<Node> getAllUserWithoutCard(String id, boolean disabled) throws DubboProviderException;

    /**
     * @Description: 根据userId和类型查找对应的名片
     *
     * @param params
     * @return java.util.List<java.util.Map>
     * @Author wanji
     * @Date 2019/12/10 17:45
     **/
    List<Map> listCardsByCondition(Map<String, Object> params) throws DubboProviderException;

    /**
     * @Description: 批量关联业务账号
     *
     * @param accountMappings
     * @return void
     * @Author wanji
     * @Date 2020/4/11 9:21
     **/
    void batchRelateBusinessAccounts(AccountMappings accountMappings) throws DubboProviderException;

    /**
     * @Description: 根据用户id和业务账号ids批量取消关联
     *
     * @param businessAccountIds
     * @return void
     * @Author wanji
     * @Date 2020/4/11 15:50
     **/
    void batchDeleteByAccountIds(String UserId, List<String> businessAccountIds) throws DubboProviderException;

    List<AccountMappings> listAccountMappingsByUserId(String userId) throws DubboProviderException;

    void batchRelateUsers(String businessAccountId,List<String> userIds) throws DubboProviderException;
}
