package net.wanji.databus.provider.identity.identity;


import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.mapper.ExportImportMapper;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.common.framework.rest.Node;
import net.wanji.databus.entity.identity.identity.AppBusinessAccount;
import net.wanji.databus.entity.identity.identity.Organization;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author wanji
 * @Date 2020/3/17 13:33
 */
public interface AppBusinessAccountProvider extends BaseDubboInterface<AppBusinessAccount>, ExportImportMapper {
    /**
     * @Description: 批量导入业务账户
     *
     * @param appId
     * @param businessAccountIds
     * @return void
     * @Author wanji
     * @Date 2020/3/18 16:58
     **/
    JsonViewObject batchImport(String appId, List<Map> businessAccountIds) throws DubboProviderException;

    /**
     * @Description: 获取应用用户的二级目录树结构
     *
     * @param disabled
     * @return java.util.List<net.wanji.common.identity.rest.Node>
     * @Author wanji
     * @Date 2020/3/19 13:22
     **/
    List<Node> getCatalog(boolean disabled) throws DubboProviderException;

    List<Map<String, Object>> newFindByMap(Map<String, Object> map);

    List<AppBusinessAccount> listBusinessAccountsByAppId(String appId,String roleId);

    void cancleAppAdmin(Map<String, Object> params) throws DubboProviderException;

    void batchRelateApplication(String businessAccountId,List<String> appIds) throws DubboProviderException;

    /**
     * @Author wanji
     * @Description 根据应用ID查询机构
     * @Date 13:41 2020/6/29
     * @Param [appId]
     * @return Organization
     * @throws
     */
    List<Organization> listOrganizationsByAppId(String appId, String keyword);

    /**
     * @Author wanji
     * @Description 根据应用id和岗位id查询未被导入的业务账号
     * @Date 16:23 2020/9/9
     * @Param [appId, stationId]
     * @return java.util.List<AppBusinessAccount>
     * @throws
     */
    List listBusinessAccountsByAppIdAndStationId(String appId, String stationId,String keyword) throws Exception;

    List listDepartmentsByAppIdAndOrganizationId(String appId,String organizationId,String keyword) throws Exception;

    List listStationsByAppIdAndDepartmentId(String appId, String departmentId,String keyword) throws Exception;

    /**
     * @Author wanji
     * @Description 根据应用id和岗位id查询该应用的业务账号
     * @Date 17:05 2020/10/15
     * @Param [appId, stationId, keyword]
     * @return java.util.List
     * @throws
     */
    List listBusinessAccountsAllByAppIdAndStationId(String appId, String stationId,String keyword) throws Exception;

    public List<Node> lazyNode(List<String> ids, String type) throws Exception;
}
