package net.wanji.databus.provider.identity.identity;

import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.Node;
import net.wanji.common.framework.rest.Page;
import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.databus.entity.identity.identity.BusinessAccount;
import net.wanji.databus.entity.identity.identity.User;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @Description:
 * @Author wanji
 * @Date 2019/11/27 18:45
 **/
public interface BusinessAccountProvider extends BaseDubboInterface<BusinessAccount> {

    /**
     * @Description: 根据用户名查找企业用户
     *
     * @param username
     * @return net.wanji.design.entity.design.authcenter.BusinessAccount
     * @Author wanji
     * @Date 2019/11/26 17:38
     **/
    BusinessAccount findByUsername(String username) throws DubboProviderException;

//    /**
//     * @Description: 取消用户角色分配
//     *
//     * @param ids
//     * @return net.wanji.common.identity.rest.JsonViewObject
//     * @Author wanji
//     * @Date 2019/11/28 21:42
//     **/
//    String cancelAssignRole(String ids) throws DubboProviderException;

    /**
     * @Description: 构建Node四级节点,
     *
     * @param companyUserList
     * @param disabled 树结构中非最底层叶子节点的操作状态
     * @return java.util.List<net.wanji.common.identity.rest.Node>
     * @Author wanji
     * @Date 2019/11/28 21:42
     **/
    List<Node> buildNodeList(List<BusinessAccount> companyUserList, boolean disabled) throws DubboProviderException;

    /**
     * @Description: 获取企业/部门/岗位/公司用户四级目录
     *
     * @param disabled 树结构中非最底层叶子节点的操作状态
     * @return java.util.List<net.wanji.common.identity.rest.Node>
     * @Author wanji
     * @Date 2019/12/3 14:43
     **/
    List<Node> getCatalog(boolean disabled) throws DubboProviderException;

    List<Node> getCatalogByBusinessAccountIds(List<String> businessAccountIds) throws DubboProviderException;

    /**
     * @Description: 根据id集合禁用或者取消禁用
     *
     * @param status
     * @param ids
     * @return void
     * @Author wanji
     * @Date 2019/12/5 17:48
     **/
    void disableByIds(String status, List ids) throws DubboProviderException;

    /**
     * @Description:
     *
     * @param
     * @return net.wanji.common.identity.rest.Page<net.wanji.design.entity.design.authcenter.BusinessAccount>
     * @Author wanji
     * @Date 2019/12/24 10:47
     **/
    Page<BusinessAccount> findAllByDepartmentIdAndPage(Page page, Map map) throws DubboProviderException;

    List<String> findUserByCompanyUserId(List<String> CompanyUserId);

    /**
     * @Description: 根据业务账号查找其所拥有的微服务菜单权限
     *
     * @param params
     * @return java.util.List<java.lang.String>
     * @Author peng.zhang6
     * @Date 2020/4/15 11:04
     **/
    List<String> listAuthorityIdsByBusinessAccountId(Map<String,String> params);

    /**
     * @Description: 通过应用id查询，机构，部门，岗位，业务账号等级联信息
     *
     * @param appId
     * @return java.util.List<com.wanji.identity.identity.rest.Node>
     * @Author peng.zhang6
     * @Date 2020/4/16 11:54
     **/
    List<Node>  findCascadeInfoByAppId(String appId ,boolean  disabled) throws DubboProviderException;

    /**
     * @Description: 根据appId查询业务账号信息
     *
     * @param appId
     * @return java.util.List<com.wanji.identity.entity.identity.BusinessAccount>
     * @Author peng.zhang6
     * @Date 2020/4/27 11:54
     **/
    List<BusinessAccount> getBusinessAccountByAppId(String appId) throws DubboProviderException;

    /**
     * @Description: 根据部门id和应用id查询业务账号信息
     *
     * @param deptId
     * @param appId
     * @return java.util.List<com.wanji.identity.entity.identity.User>
     * @Author peng.zhang6
     * @Date 2020/4/27 11:54
     **/
    List<BusinessAccount> getBusinessAccountBydeptIdAndAppId(String deptId, String appId);

    /**
     * @Description: 根据部门id和应用id,岗位id查询用户
     *
     * @param deptId
     * @param appId
     * @param stationId
     * @return java.util.List<com.wanji.identity.entity.identity.BusinessAccount>
     * @Author peng.zhang6
     * @Date 2020/4/27 16:55
     **/
    List<BusinessAccount> getBusinessAccountByCondition(String deptId,String appId,String stationId);

    List<Node> getBusinessAccountCatalog(String appId) throws DubboProviderException;

    List<BusinessAccount> findByAppId(String appId);

    /**
     * @Description: 根据崗位id和应用id查询业务账号信息
     *
     * @param stationId
     * @param appId
     * @return java.util.List<com.wanji.identity.entity.identity.User>
     * @Author peng.zhang6
     * @Date 2020/4/27 11:54
     **/
    List<BusinessAccount> getBusinessAccountBystationIdAndAppId(String stationId, String appId);

    List<Node> getCatalogByAppId(String appId) throws DubboProviderException;

    List<Node> listUsersByBusinessAccountId(String businessAccountId) throws DubboProviderException;

    List<User> findUsersByBusinessAccountId(String businessAccountId) throws DubboProviderException;

    List<Node> listApplicationsByBusinessAccountId(String businessAccountId) throws DubboProviderException;

    /**
     *  根据appId 获取已经导入的应用帐号
     * @param appId
     * @return
     * @throws DubboProviderException
     */
    List<Node> getImportedBusinessAccountCatalog(String appId) throws DubboProviderException;

    /**
     * @Author wanji
     * @Description
     * @Date 14:06 2020/9/11
     * @Param [type, keyword]
     * @return java.util.List<net.wanji.common.framework.rest.Node>
     * @throws
     */
    List listInfoByTypeAndKeyword(String type, String keyword) throws Exception;

    List<BusinessAccount> findByIds(Set<String> consumerIds);
}
