package net.wanji.databus.provider.identity.logcenter;

import net.wanji.common.framework.dubbointerface.BaseLogInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.databus.entity.monitor.statistics.*;
import net.wanji.databus.entity.monitor.statistics.*;

import java.util.List;
import java.util.Map;

/**
 * @author wanji
 */
public interface LoginLogProvider extends BaseLogInterface {
    /**
     * @return Integer
     * @Description: 获取日期总数
     * @Author wanji
     **/
    Integer countDate() throws DubboProviderException;

    Integer countIntervalDate(Long startDate, Long endDate) throws DubboProviderException;

    /**
     * @param startDate
     * @param endDate
     * @Description: 统计指定时间间隔内日启动用户数(无分页)
     **/
    List<ActiveUser> countUserByDate(Long startDate, Long endDate, Integer startRowNum, Integer pageSize) throws DubboProviderException;

    /**
     * @param startDate
     * @param endDate
     * @return int
     * @Description: 统计周活跃用户
     * @Author
     * @Date 2020/6/15 14:55
     **/
    Integer countUserNumByDate(Long startDate, Long endDate) throws DubboProviderException;

    /**
     * @throws
     * @Description 获取设备的echart图表信息
     */
    List<DeviceChartInfo> getDeviceChartData(Long startDate, Long endDate, String loginType, Integer startRowNum, Integer pageSize) throws DubboProviderException;

    /**
     * @param startRowNum
     * @param pageSize
     * @param startDate
     * @param endDate
     * @Description: 统计指定时间间隔内各IP地址启动用户数
     **/
    List<RegionalUser> countUserByIpAndPage(Integer startRowNum, Integer pageSize, Long startDate, Long endDate) throws DubboProviderException;

    /**
     * @param startDate
     * @param endDate
     * @Description: 统计指定时间间隔内各IP地址启动用户数
     **/
    List<RegionalUser> countUserByIp(Long startDate, Long endDate) throws DubboProviderException;

    /**
     * 根据条件按日期统计客户端版本使用情况
     *
     * @param startDate
     * @param endDate
     * @param clientVersion
     * @return
     */
    List<VersionDateStatistics> countVersionInfoByDate(Long startDate, Long endDate, String clientVersion) throws DubboProviderException;

    /**
     * 根据条件按日期统计客户端版本使用统计
     *
     * @return
     */
    List<VersionStatistics> countVersionInfoByVersion(Long startDate, Long endDate, Integer startRowNum, Integer pageSize) throws DubboProviderException;

    /**
     * 获取版本列表
     *
     * @return
     */
    List<String> versionList(Long startDate, Long endDate) throws DubboProviderException;

    /**
     * @param map
     * @return java.util.List<UserTrends>
     * @Description: 分页统计日启动用户数、访问次数及独立ip数
     * @Author
     * @Date 2020/6/15 14:57
     **/
    List<UserTrends> countUserInfoByDate(Map<String, Integer> map) throws DubboProviderException;

    List<Map<String, Object>> queryByDate(Long startDate, Long endDate) throws DubboProviderException;
}
