package net.wanji.databus.provider.manage.systemsetting;

import net.wanji.common.framework.dubbointerface.BaseDubboInterface;
import net.wanji.common.framework.exception.DubboProviderException;
import net.wanji.common.framework.rest.Node;
import net.wanji.databus.entity.manage.systemsetting.Menu;

import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * @author wanji
 * @date 2019/3/4
 */
public interface MenuProvider extends BaseDubboInterface<Menu> {
    /**
     * 新建菜单时获取可能的上级菜单列表
     *
     * @param id
     * @return
     * @throws DubboProviderException
     */
    List<Menu> getLowerMenu(String id) throws DubboProviderException;

    /**
     * 获取树形菜单
     *
     * @param systemId
     * @param authObjIdList
     * @return
     * @throws DubboProviderException
     */
    List<Menu> getTreeMenu(String systemId, Set<String> authObjIdList) throws DubboProviderException;

    /**
     * @param
     * @return java.util.List<net.wanji.common.framework.rest.Node>
     * @Description: 获取所有菜单列表
     * @Author wanji
     * @Date 2019/12/2 14:54
     **/
    List<Node> getAllTreeMenu(List<String> authMenuIdList, String systemId) throws DubboProviderException;


    /**
     * @param
     * @return java.util.List<net.wanji.common.framework.rest.Node>
     * @Description: 获取顶级菜单列表树形结构
     * @Author wanji
     * @Date 2019/11/30 12:44
     **/
    List<Node> getTopTreeMenu(String systemId) throws DubboProviderException;

    /**
     * 批量更新菜单
     *
     * @param mapList
     * @throws DubboProviderException
     */
    void updateBatch(List<Map<String, Object>> mapList) throws DubboProviderException;

    /**
     * @param id
     * @param currentMenuId
     * @return java.util.List<net.wanji.design.entity.design.platformsetup.Menu>
     * @Description: 编辑菜单时获取可能的上级菜单列表
     * @Author wanji
     * @Date 2019/11/30 15:59
     **/
    List<Menu> getLowerMenuWhenUpdate(String id, String currentMenuId) throws DubboProviderException;


    /**
     * 通过用户Id查询菜单权限信息
     *
     * @param userId
     * @return
     * @Author shun.yin
     * @Date 2020/3/17
     */
    List<String> userMenuNodes(String userId) throws DubboProviderException;

    /**
     * 更新用户菜单权限
     * @param params userId:'',menuIds:[]
     * @return
     * @throws DubboProviderException
     */
    boolean updateUserMenus(Map<String,Object> params) throws Exception;

    /**
     * 通过用户Id获取对应菜单权限
     * @param userId 用户id
     * @return
     * @throws DubboProviderException
     */
    List<Menu> loginMenus(String userId) throws DubboProviderException;

    List<Menu> queryMenusByParentId(String userId,String parentId, Boolean isRecursion) throws Exception;
}
