package net.wanji.databus.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.Date;
import java.util.List;

@NoArgsConstructor
@Data
@ApiModel(value = "AbnormalCrossListVO", description = "问题路口列表元素")
public class AbnormalCrossListVO {
    @ApiModelProperty(value = "路口ID")
    private String id;
    @ApiModelProperty(value = "路口名称")
    private String name;
    @ApiModelProperty(value = "是否信控路口：1是；0否")
    private Integer isSignal;
    @ApiModelProperty(value = "失衡方向 如 1,2,3")
    private String unbalanceDirs;
    @ApiModelProperty(value = "拥堵方向 如 1,2,3")
    private String congestionDirs;
    @ApiModelProperty(value = "溢出方向 如 1,2,3")
    private String spilloverDirs;
    @ApiModelProperty(value = "路口状态 0正常 1失衡 2拥堵 3溢出")
    private Integer realtimeStatus;
    @ApiModelProperty(value = "开始时间 格式 08:20:23")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "HH:mm:ss", timezone = "GMT+8")
    private Date startTime;
    @ApiModelProperty(value = "持续时长 分钟")
    private Long duration;
    @ApiModelProperty(value = "优化状态 1优化中 2未优化")
    private Integer optStatus;
    @JsonIgnore
    // 路口坐标字符串
    private String locationStr;
    @ApiModelProperty(value = "路口坐标")
    private List<Double> location;
    @ApiModelProperty(value = "关联路口坐标列表")
    private List<List<Double>> ridLocationList;
    @ApiModelProperty(value = "关联路口wkt列表")
    private List<String> ridWktList;
    @ApiModelProperty(value = "是否失衡：0否；1是")
    private Integer isUnbalance;
    @ApiModelProperty(value = "是否溢出：0否；1是")
    private Integer isSpillover;
    @ApiModelProperty(value = "是否拥堵：0否；1是")
    private Integer isCongestion;
    @ApiModelProperty(value = "拥堵指数")
    private Double congestionIndex;
    @ApiModelProperty(value = "同比", notes = "同比增长率= (本期数 - 同期数) / 同期数 × 100%；同比：取上一周同一时段数据")
    private Double lastWeekIndex;
    @ApiModelProperty(value = "环比", notes = "增长率= (本期数 - 上期数) / 上期数 × 100%；环比：取上一时段数据")
    private Double lastPeriodIndex;
    private Integer batchTime;
    @ApiModelProperty(value = " 0-偶发性 1-常发性", notes = "一个月内超过三次")
    private int frequent;
}
