package net.wanji.databus.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.Pattern;
import java.util.List;

/**
 * @author Kent HAN
 * @date 2023/6/9 13:52
 */
@Data
@ApiModel(value = "AreaInfoVO", description = "区域信息")
public class AreaInfoVO {
    @ApiModelProperty(value = "区划类型：1行政区划；2交警辖区；3商圈；4交通小区；5热点区域；6道路")
    private Integer type;

    @ApiModelProperty(value = "父节点")
    private Integer parentCode;

    @ApiModelProperty(value = "区域ID")
    private Integer areaId;

    @ApiModelProperty(value = "区域名称", required = true)
    @Pattern(regexp = "^[\\u4E00-\\u9FA5\\w\\-]{0,20}$", message = "区域名称只能包含中文、英文、数字、下划线和中横线,0~20个字符")
    private String areaName;

    @ApiModelProperty(value = "道路名称")
    @Pattern(regexp = "^[\\u4E00-\\u9FA5\\w\\-]{0,20}$", message = "道路名称只能包含中文、英文、数字、下划线和中横线,0~20个字符")
    private String roadName;

    @ApiModelProperty(value = "备注", required = true)
    @Pattern(regexp = "^[\\u4E00-\\u9FA5\\w\\-]{0,200}$", message = "备注只能包含中文、英文、数字、下划线和中横线,0~200个字符")
    private String remark;

    @ApiModelProperty(value = "路口数组", required = true)
    private List<CrossIdAndNameVO> crossIdAndNameList;

    @ApiModelProperty(value = "道路区域坐标")
    private String wkt;

    @ApiModelProperty(value = "其他区域坐标")
    private List<String> wktList;

}
