package net.wanji.databus.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Pattern;
import java.util.List;

/**
 * 时间表下发VO
 *
 * @author wuxiaokai
 * @date 2022/11/23 14:11:09
 */
@Setter
@Getter
@ApiModel(value = "信号机时间表下发输入参数", description = "信号机时间表下发输入参数")
public class ScheduleSendVO {

    @ApiModelProperty(value = "路口编号", notes = "路口编号")
    @NotBlank(message = "路口编号不可为空")
    @Pattern(regexp = "^[A-Za-z0-9]{11}$", message = "路口编号只能包含英文、数字，必须11个字符")
    private String crossCode;
    @ApiModelProperty(value = "时间表", notes = "时间表")
    @NotEmpty(message = "时间表不可为空")
    private List<Schedule> schedules;

    @Setter
    @Getter
    public static class Schedule {

        /**
         * 调度号
         */
        private String scheduleNo;
        /**
         * 星期列表
         */
        @ApiModelProperty(value = "星期列表", notes = "星期列表")
        private List<Week> weeks;

        /**
         * 特殊日期列表
         */
        @ApiModelProperty(value = "特殊日期列表", notes = "特殊日期列表")
        private List<SpecialDay> specialDays;

        @Setter
        @Getter
        public static class Week {

            @ApiModelProperty(value = "星期", notes = "星期")
            private Integer weekNum;
            @ApiModelProperty(value = "计划号", notes = "计划号")
            private Integer planNo;
        }

        @Setter
        @Getter
        public static class SpecialDay {

            /**
             * 日期 2019-05-01
             */
            @ApiModelProperty(value = "日期", notes = "日期")
            private String dateStr;
            /**
             * 计划号
             */
            @ApiModelProperty(value = "计划号", notes = "计划号")
            private Integer planNo;

        }
    }
}
